@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,6 +22,6 @@
 
 #define BACKTRACE_MAX 128
 
-extern void weechat_backtrace ();
+extern void weechat_backtrace (void);
 
 #endif /* WEECHAT_BACKTRACE_H */
