@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,10 +26,10 @@ extern char *weechat_log_filename;
 extern FILE *weechat_log_file;
 extern int weechat_log_use_time;
 
-extern void log_init ();
-extern void log_close ();
+extern void log_init (void);
+extern void log_close (void);
 extern void log_printf (const char *message, ...);
 extern void log_printf_hexa (const char *spaces, const char *string);
-extern int log_crash_rename ();
+extern int log_crash_rename (void);
 
 #endif /* WEECHAT_LOG_H */
