@@ -1,7 +1,7 @@
 /*
  * core-proxy.c - proxy functions
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -254,19 +254,17 @@ proxy_create_option (const char *proxy_name, int index_option,
                      const char *value)
 {
     struct t_config_option *ptr_option;
-    int length;
     char *option_name;
 
     ptr_option = NULL;
 
-    length = strlen (proxy_name) + 1 +
-        strlen (proxy_option_string[index_option]) + 1;
-    option_name = malloc (length);
-    if (!option_name)
+    if (string_asprintf (&option_name,
+                         "%s.%s",
+                         proxy_name,
+                         proxy_option_string[index_option]) < 0)
+    {
         return NULL;
-
-    snprintf (option_name, length, "%s.%s",
-              proxy_name, proxy_option_string[index_option]);
+    }
 
     switch (index_option)
     {
@@ -474,7 +472,7 @@ proxy_new (const char *name, const char *type, const char *ipv6,
  */
 
 void
-proxy_use_temp_proxies ()
+proxy_use_temp_proxies (void)
 {
     struct t_proxy *ptr_temp_proxy, *next_temp_proxy;
     int i, num_options_ok;
@@ -568,7 +566,7 @@ proxy_free (struct t_proxy *proxy)
  */
 
 void
-proxy_free_all ()
+proxy_free_all (void)
 {
     while (weechat_proxies)
     {
@@ -649,7 +647,7 @@ proxy_add_to_infolist (struct t_infolist *infolist, struct t_proxy *proxy)
  */
 
 void
-proxy_print_log ()
+proxy_print_log (void)
 {
     struct t_proxy *ptr_proxy;
 
