@@ -1,7 +1,7 @@
 /*
  * core-upgrade.c - save/restore session data of WeeChat core
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -376,7 +376,7 @@ upgrade_weechat_save_layout_window (struct t_upgrade_file *upgrade_file)
  */
 
 int
-upgrade_weechat_save ()
+upgrade_weechat_save (void)
 {
     int rc;
     struct t_upgrade_file *upgrade_file;
@@ -409,7 +409,7 @@ upgrade_weechat_read_buffer (struct t_infolist *infolist)
     const char *key, *var_name, *name, *plugin_name, *ptr_id;
     const char *str;
     char option_name[64], *option_key, *option_var, *error;
-    int index, length, main_buffer;
+    int index, main_buffer;
     long long id;
 
     /* "id" is new in WeeChat 4.3.0 */
@@ -612,11 +612,8 @@ upgrade_weechat_read_buffer (struct t_infolist *infolist)
         key = infolist_string (infolist, option_name);
         if (!key)
             break;
-        length = 16 + strlen (key) + 1;
-        option_key = malloc (length);
-        if (option_key)
+        if (string_asprintf (&option_key, "key_bind_%s", key) >= 0)
         {
-            snprintf (option_key, length, "key_bind_%s", key);
             snprintf (option_name, sizeof (option_name),
                       "key_command_%05d", index);
             gui_buffer_set (ptr_buffer, option_key,
@@ -635,11 +632,8 @@ upgrade_weechat_read_buffer (struct t_infolist *infolist)
         var_name = infolist_string (infolist, option_name);
         if (!var_name)
             break;
-        length = 32 + strlen (var_name) + 1;
-        option_var = malloc (length);
-        if (option_var)
+        if (string_asprintf (&option_var, "localvar_set_%s", var_name) >= 0)
         {
-            snprintf (option_var, length, "localvar_set_%s", var_name);
             snprintf (option_name, sizeof (option_name),
                       "localvar_value_%05d", index);
             gui_buffer_set (ptr_buffer, option_var,
@@ -910,7 +904,7 @@ upgrade_weechat_read_cb (const void *pointer, void *data,
  */
 
 int
-upgrade_weechat_load ()
+upgrade_weechat_load (void)
 {
     int rc;
     struct t_upgrade_file *upgrade_file;
@@ -983,7 +977,7 @@ upgrade_weechat_remove_file_cb (void *data, const char *filename)
  */
 
 void
-upgrade_weechat_end ()
+upgrade_weechat_end (void)
 {
     struct timeval tv_now;
     long long time_diff;
