@@ -1,7 +1,7 @@
 /*
  * core-url.c - URL transfer
  *
- * Copyright (C) 2012-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2012-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -1293,7 +1293,7 @@ weeurl_option_add_to_infolist (struct t_infolist *infolist,
  */
 
 void
-weeurl_init ()
+weeurl_init (void)
 {
     curl_global_init (CURL_GLOBAL_ALL);
 }
@@ -1303,7 +1303,7 @@ weeurl_init ()
  */
 
 void
-weeurl_end ()
+weeurl_end (void)
 {
     curl_global_cleanup ();
 }
