@@ -1,7 +1,7 @@
 /*
  * core-utf8.c - UTF-8 string functions
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -46,7 +46,7 @@ int local_utf8 = 0;
  */
 
 void
-utf8_init ()
+utf8_init (void)
 {
     local_utf8 = (string_strcasecmp (weechat_local_charset, "utf-8") == 0);
 }
