@@ -1,7 +1,7 @@
 /*
  * hook-process.c - WeeChat process hook
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -787,7 +787,7 @@ error:
  */
 
 void
-hook_process_exec ()
+hook_process_exec (void)
 {
     struct t_hook *ptr_hook, *next_hook;
     struct t_hook_exec_cb hook_exec_cb;
