@@ -1,7 +1,7 @@
 /*
  * gui-curses-main.c - main loop for Curses GUI
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -163,7 +163,7 @@ gui_main_signal_sigint (int signo)
  */
 
 void
-gui_main_init ()
+gui_main_init (void)
 {
     struct t_gui_buffer *ptr_buffer;
     char title[256];
@@ -231,12 +231,7 @@ gui_main_init ()
                             gui_term_cols, gui_term_lines, 100, 100))
         {
             gui_current_window = gui_windows;
-
-            if (CONFIG_STRING(config_look_window_title)
-                && CONFIG_STRING(config_look_window_title)[0])
-            {
-                gui_window_set_title (CONFIG_STRING(config_look_window_title));
-            }
+            gui_window_set_title (CONFIG_STRING(config_look_window_title));
         }
 
         /* switch to buffer */
@@ -269,7 +264,7 @@ gui_main_signal_sigwinch (int signo)
  */
 
 void
-gui_main_debug_libs ()
+gui_main_debug_libs (void)
 {
 #if defined(NCURSES_VERSION) && defined(NCURSES_VERSION_PATCH)
     gui_chat_printf (NULL, "    ncurses: %s (patch %d)",
@@ -284,7 +279,7 @@ gui_main_debug_libs ()
  */
 
 void
-gui_main_refreshes ()
+gui_main_refreshes (void)
 {
     struct t_gui_window *ptr_win;
     struct t_gui_buffer *ptr_buffer;
@@ -391,7 +386,7 @@ gui_main_refreshes ()
  */
 
 void
-gui_main_loop ()
+gui_main_loop (void)
 {
     struct t_hook *hook_fd_keyboard;
     int send_signal_sigwinch;
@@ -526,13 +521,6 @@ gui_main_end (int clean_exit)
         /* delete global history */
         gui_history_global_free ();
 
-        /* reset title */
-        if (CONFIG_STRING(config_look_window_title)
-            && CONFIG_STRING(config_look_window_title)[0])
-        {
-            gui_window_set_title (NULL);
-        }
-
         /* end color */
         gui_color_end ();
 
