@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -43,7 +43,7 @@ struct t_gui_window_curses_objects
 extern int gui_window_current_color_attr;
 extern int gui_window_current_emphasis;
 
-extern void gui_window_read_terminal_size ();
+extern void gui_window_read_terminal_size (void);
 extern void gui_window_clear (WINDOW *window, int fg, int bg);
 extern void gui_window_clrtoeol (WINDOW *window);
 extern void gui_window_save_style (WINDOW *window);
@@ -59,7 +59,7 @@ extern void gui_window_set_custom_color_fg_bg (WINDOW *window, int fg, int bg,
 extern void gui_window_set_custom_color_pair (WINDOW *window, int pair);
 extern void gui_window_set_custom_color_fg (WINDOW *window, int fg);
 extern void gui_window_set_custom_color_bg (WINDOW *window, int bg);
-extern void gui_window_toggle_emphasis ();
+extern void gui_window_toggle_emphasis (void);
 extern void gui_window_emphasize (WINDOW *window, int x, int y, int count);
 extern void gui_window_string_apply_color_fg (unsigned char **str,
                                               WINDOW *window);
