@@ -1,7 +1,7 @@
 /*
  * main.c - entry point for headless mode (no GUI)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -42,7 +42,7 @@
  */
 
 void
-daemonize ()
+daemonize (void)
 {
     pid_t pid;
     int fd, i;
