@@ -1,7 +1,7 @@
 /*
  * gui-bar.c - bar functions (used by all GUI)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -1835,7 +1835,7 @@ gui_bar_new_default (enum t_gui_bar_default bar)
  */
 
 void
-gui_bar_use_temp_bars ()
+gui_bar_use_temp_bars (void)
 {
     struct t_gui_bar *ptr_temp_bar, *next_temp_bar;
     int i, num_options_ok;
@@ -1908,10 +1908,9 @@ gui_bar_use_temp_bars ()
  */
 
 void
-gui_bar_create_default_input ()
+gui_bar_create_default_input (void)
 {
     struct t_gui_bar *ptr_bar;
-    int length;
     char *buf;
 
     /* search an input_text item */
@@ -1922,18 +1921,13 @@ gui_bar_create_default_input ()
         if (ptr_bar)
         {
             /* add item "input_text" to input bar */
-            length = 1;
-            if (CONFIG_STRING(ptr_bar->options[GUI_BAR_OPTION_ITEMS]))
-                length += strlen (CONFIG_STRING(ptr_bar->options[GUI_BAR_OPTION_ITEMS]));
-            length += 1; /* "," */
-            length += strlen (gui_bar_item_names[GUI_BAR_ITEM_INPUT_TEXT]);
-            buf = malloc (length);
-            if (buf)
+            if (string_asprintf (
+                    &buf,
+                    "%s,%s",
+                    (CONFIG_STRING(ptr_bar->options[GUI_BAR_OPTION_ITEMS])) ?
+                    CONFIG_STRING(ptr_bar->options[GUI_BAR_OPTION_ITEMS]) : "",
+                    gui_bar_item_names[GUI_BAR_ITEM_INPUT_TEXT]) >= 0)
             {
-                snprintf (buf, length, "%s,%s",
-                          (CONFIG_STRING(ptr_bar->options[GUI_BAR_OPTION_ITEMS])) ?
-                          CONFIG_STRING(ptr_bar->options[GUI_BAR_OPTION_ITEMS]) : "",
-                          gui_bar_item_names[GUI_BAR_ITEM_INPUT_TEXT]);
                 config_file_option_set (ptr_bar->options[GUI_BAR_OPTION_ITEMS], buf, 1);
                 gui_chat_printf (NULL, _("Bar \"%s\" updated"),
                                  gui_bar_default_name[GUI_BAR_DEFAULT_INPUT]);
@@ -1958,7 +1952,7 @@ gui_bar_create_default_input ()
  */
 
 void
-gui_bar_create_default_title ()
+gui_bar_create_default_title (void)
 {
     struct t_gui_bar *ptr_bar;
 
@@ -1980,7 +1974,7 @@ gui_bar_create_default_title ()
  */
 
 void
-gui_bar_create_default_status ()
+gui_bar_create_default_status (void)
 {
     struct t_gui_bar *ptr_bar;
 
@@ -2002,7 +1996,7 @@ gui_bar_create_default_status ()
  */
 
 void
-gui_bar_create_default_nicklist ()
+gui_bar_create_default_nicklist (void)
 {
     struct t_gui_bar *ptr_bar;
 
@@ -2024,7 +2018,7 @@ gui_bar_create_default_nicklist ()
  */
 
 void
-gui_bar_create_default ()
+gui_bar_create_default (void)
 {
     gui_bar_create_default_input ();
     gui_bar_create_default_title ();
@@ -2219,7 +2213,7 @@ gui_bar_free (struct t_gui_bar *bar)
  */
 
 void
-gui_bar_free_all ()
+gui_bar_free_all (void)
 {
     while (gui_bars)
     {
@@ -2389,7 +2383,7 @@ gui_bar_add_to_infolist (struct t_infolist *infolist,
  */
 
 void
-gui_bar_print_log ()
+gui_bar_print_log (void)
 {
     struct t_gui_bar *ptr_bar;
     int i, j;
