@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -30,10 +30,11 @@ extern char *gui_input_clipboard;
 
 extern void gui_input_replace_input (struct t_gui_buffer *buffer,
                                      const char *new_input);
-extern void gui_input_paste_pending_signal ();
+extern void gui_input_paste_pending_signal (void);
 extern void gui_input_text_changed_modifier_and_signal (struct t_gui_buffer *buffer,
                                                         int save_undo,
                                                         int stop_completion);
+extern void gui_input_search_signal (struct t_gui_buffer *buffer);
 extern void gui_input_set_pos (struct t_gui_buffer *buffer, int pos);
 extern void gui_input_insert_string (struct t_gui_buffer *buffer,
                                      const char *string);
@@ -44,6 +45,7 @@ extern void gui_input_complete_next (struct t_gui_buffer *buffer);
 extern void gui_input_complete_previous (struct t_gui_buffer *buffer);
 extern void gui_input_search_text_here (struct t_gui_buffer *buffer);
 extern void gui_input_search_text (struct t_gui_buffer *buffer);
+extern void gui_input_search_history (struct t_gui_buffer *buffer);
 extern void gui_input_search_compile_regex (struct t_gui_buffer *buffer);
 extern void gui_input_search_switch_case (struct t_gui_buffer *buffer);
 extern void gui_input_search_switch_regex (struct t_gui_buffer *buffer);
@@ -78,6 +80,7 @@ extern void gui_input_history_local_previous (struct t_gui_buffer *buffer);
 extern void gui_input_history_local_next (struct t_gui_buffer *buffer);
 extern void gui_input_history_global_previous (struct t_gui_buffer *buffer);
 extern void gui_input_history_global_next (struct t_gui_buffer *buffer);
+extern void gui_input_history_use_get_next (struct t_gui_buffer *buffer);
 extern void gui_input_grab_key (struct t_gui_buffer *buffer, int command,
                                 const char *delay);
 extern void gui_input_grab_mouse (struct t_gui_buffer *buffer, int area);
