@@ -1,7 +1,7 @@
 /*
  * gui-line.c - line functions (used by all GUI)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -55,7 +55,7 @@
  */
 
 struct t_gui_lines *
-gui_line_lines_alloc ()
+gui_line_lines_alloc (void)
 {
     struct t_gui_lines *new_lines;
 
