@@ -1,7 +1,7 @@
 /*
  * gui-window.c - window functions (used by all GUI)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -2099,7 +2099,7 @@ gui_window_add_to_infolist (struct t_infolist *infolist,
  */
 
 void
-gui_window_print_log ()
+gui_window_print_log (void)
 {
     struct t_gui_window *ptr_window;
     struct t_gui_window_scroll *ptr_scroll;
