@@ -1,7 +1,7 @@
 /*
  * buflist-config.c - buflist configuration options (file buflist.conf)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -105,7 +105,7 @@ buflist_config_reload (const void *pointer, void *data,
  */
 
 void
-buflist_config_free_signals_refresh ()
+buflist_config_free_signals_refresh (void)
 {
     int i;
 
@@ -169,7 +169,7 @@ buflist_config_signal_buffer_cb (const void *pointer, void *data,
  */
 
 void
-buflist_config_hook_signals_refresh ()
+buflist_config_hook_signals_refresh (void)
 {
     char **all_signals, **signals;
     const char *ptr_signals_refresh;
@@ -469,7 +469,7 @@ buflist_config_change_format (const void *pointer, void *data,
  */
 
 int
-buflist_config_init ()
+buflist_config_init (void)
 {
     buflist_config_file = weechat_config_new (
         BUFLIST_CONFIG_PRIO_NAME,
@@ -578,7 +578,8 @@ buflist_config_init ()
             buflist_config_file, buflist_config_section_look,
             "nick_prefix_empty", "boolean",
             N_("when the nick prefix is enabled, display a space instead if "
-               "there is no nick prefix on the buffer"),
+               "there is no nick prefix on the buffer (only for channel, "
+               "private and list buffers)"),
             NULL, 0, 0, "on", NULL, 0,
             NULL, NULL, NULL,
             &buflist_config_change_buflist, NULL, NULL,
@@ -804,7 +805,7 @@ buflist_config_init ()
  */
 
 int
-buflist_config_read ()
+buflist_config_read (void)
 {
     int rc;
 
@@ -825,7 +826,7 @@ buflist_config_read ()
  */
 
 int
-buflist_config_write ()
+buflist_config_write (void)
 {
     return weechat_config_write (buflist_config_file);
 }
@@ -835,7 +836,7 @@ buflist_config_write ()
  */
 
 void
-buflist_config_free ()
+buflist_config_free (void)
 {
     int i;
 
