@@ -2,7 +2,7 @@
  * buflist-info.c - infolist hook for buflist plugin
  *
  * Copyright (C) 2019 Simmo Saan <simmo.saan@gmail.com>
- * Copyright (C) 2019-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2019-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -114,7 +114,7 @@ buflist_info_infolist_buflist_cb (const void *pointer, void *data,
  */
 
 void
-buflist_info_init ()
+buflist_info_init (void)
 {
     weechat_hook_infolist (
         "buflist", N_("list of buffers in a buflist bar item"),
