@@ -1,7 +1,7 @@
 /*
  * exec-command.c - exec command
  *
- * Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -36,7 +36,7 @@
  */
 
 void
-exec_command_list ()
+exec_command_list (void)
 {
     struct t_exec_cmd *ptr_exec_cmd;
     char str_elapsed[32], str_time1[256], str_time2[256];
@@ -656,7 +656,7 @@ exec_command_exec (const void *pointer, void *data,
                    struct t_gui_buffer *buffer, int argc,
                    char **argv, char **argv_eol)
 {
-    int i, length, count;
+    int i, count;
     char *text;
     struct t_exec_cmd *ptr_exec_cmd, *ptr_next_exec_cmd;
 
@@ -680,11 +680,8 @@ exec_command_exec (const void *pointer, void *data,
         ptr_exec_cmd = exec_command_search_running_id (argv[2]);
         if (ptr_exec_cmd && ptr_exec_cmd->hook)
         {
-            length = strlen (argv_eol[3]) + 1 + 1;
-            text = malloc (length);
-            if (text)
+            if (weechat_asprintf (&text, "%s\n", argv_eol[3]) >= 0)
             {
-                snprintf (text, length, "%s\n", argv_eol[3]);
                 weechat_hook_set (ptr_exec_cmd->hook, "stdin", text);
                 free (text);
             }
@@ -701,11 +698,8 @@ exec_command_exec (const void *pointer, void *data,
         {
             if (argc > 3)
             {
-                length = strlen (argv_eol[3]) + 1 + 1;
-                text = malloc (length);
-                if (text)
+                if (weechat_asprintf (&text, "%s\n", argv_eol[3]) >= 0)
                 {
-                    snprintf (text, length, "%s\n", argv_eol[3]);
                     weechat_hook_set (ptr_exec_cmd->hook, "stdin", text);
                     free (text);
                 }
@@ -821,7 +815,7 @@ exec_command_exec (const void *pointer, void *data,
  */
 
 void
-exec_command_init ()
+exec_command_init (void)
 {
     weechat_hook_command (
         "exec",
