@@ -1,7 +1,7 @@
 /*
  * exec.c - execution of external commands in WeeChat
  *
- * Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -115,7 +115,7 @@ exec_search_by_id (const char *id)
  */
 
 struct t_exec_cmd *
-exec_add ()
+exec_add (void)
 {
     struct t_exec_cmd *new_exec_cmd;
     int i;
@@ -244,7 +244,6 @@ exec_display_line (struct t_exec_cmd *exec_cmd, struct t_gui_buffer *buffer,
 {
     struct t_hashtable *options;
     char *line_color, *line2, str_number[32], str_tags[1024];
-    int length;
 
     if (!exec_cmd || !line)
         return;
@@ -293,12 +292,11 @@ exec_display_line (struct t_exec_cmd *exec_cmd, struct t_gui_buffer *buffer,
         else
         {
             /* add line at the end of command, after a space */
-            length = strlen (exec_cmd->pipe_command) + 1 + strlen (line_color) + 1;
-            line2 = malloc (length);
-            if (line2)
+            if (weechat_asprintf (&line2,
+                                  "%s %s",
+                                  exec_cmd->pipe_command,
+                                  line_color) >= 0)
             {
-                snprintf (line2, length,
-                          "%s %s", exec_cmd->pipe_command, line_color);
                 weechat_command_options (buffer, line2, options);
                 free (line2);
             }
@@ -310,12 +308,11 @@ exec_display_line (struct t_exec_cmd *exec_cmd, struct t_gui_buffer *buffer,
             weechat_hashtable_set (options, "commands", "-");
         if (exec_cmd->line_numbers)
         {
-            length = 32 + strlen (line_color) + 1;
-            line2 = malloc (length);
-            if (line2)
+            if (weechat_asprintf (&line2,
+                                  "%d. %s",
+                                  exec_cmd->output_line_nb,
+                                  line_color) >= 0)
             {
-                snprintf (line2, length,
-                          "%d. %s", exec_cmd->output_line_nb, line_color);
                 weechat_command_options (buffer, line2, options);
                 free (line2);
             }
@@ -645,7 +642,7 @@ exec_free (struct t_exec_cmd *exec_cmd)
  */
 
 void
-exec_free_all ()
+exec_free_all (void)
 {
     while (exec_cmds)
     {
@@ -658,7 +655,7 @@ exec_free_all ()
  */
 
 void
-exec_print_log ()
+exec_print_log (void)
 {
     struct t_exec_cmd *ptr_exec_cmd;
 
