@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -83,11 +83,11 @@ extern int exec_cmds_count;
 
 extern int exec_search_color (const char *color);
 extern struct t_exec_cmd *exec_search_by_id (const char *id);
-extern struct t_exec_cmd *exec_add ();
+extern struct t_exec_cmd *exec_add (void);
 extern int exec_process_cb (const void *pointer, void *data,
                             const char *command, int return_code,
                             const char *out, const char *err);
 extern void exec_free (struct t_exec_cmd *exec_cmd);
-extern void exec_free_all ();
+extern void exec_free_all (void);
 
 #endif /* WEECHAT_PLUGIN_EXEC_H */
