@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,8 +22,8 @@
 
 #define FSET_BAR_ITEM_NAME "fset"
 
-extern void fset_bar_item_update ();
-extern int fset_bar_item_init ();
-extern void fset_bar_item_end ();
+extern void fset_bar_item_update (void);
+extern int fset_bar_item_init (void);
+extern void fset_bar_item_end (void);
 
 #endif /* WEECHAT_PLUGIN_FSET_BAR_ITEM_H */
