@@ -1,7 +1,7 @@
 /*
  * fset-command.c - Fast Set command
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -638,7 +638,7 @@ fset_command_run_key_cb (const void *pointer, void *data,
  */
 
 void
-fset_command_init ()
+fset_command_init (void)
 {
     weechat_hook_command (
         "fset",
