@@ -1,7 +1,7 @@
 /*
  * fset-mouse.c - mouse actions for Fast Set plugin
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -311,7 +311,7 @@ fset_mouse_hsignal_cb (const void *pointer, void *data, const char *signal,
  */
 
 int
-fset_mouse_init ()
+fset_mouse_init (void)
 {
     struct t_hashtable *keys;
 
@@ -356,6 +356,6 @@ fset_mouse_init ()
  */
 
 void
-fset_mouse_end ()
+fset_mouse_end (void)
 {
 }
