@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,7 +22,7 @@
 
 #define FSET_MOUSE_HSIGNAL "fset_mouse"
 
-extern int fset_mouse_init ();
-extern void fset_mouse_end ();
+extern int fset_mouse_init (void);
+extern void fset_mouse_end (void);
 
 #endif /* WEECHAT_PLUGIN_FSET_MOUSE_H */
