@@ -1,7 +1,7 @@
 /*
  * fset-option.c - manage options displayed by Fast Set buffer
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -230,7 +230,6 @@ void
 fset_option_add_option_in_hashtable (struct t_hashtable *hashtable,
                                      struct t_fset_option *fset_option)
 {
-    int length;
     char *value;
 
     weechat_hashtable_set (hashtable, "file", fset_option->file);
@@ -251,19 +250,10 @@ fset_option_add_option_in_hashtable (struct t_hashtable *hashtable,
     weechat_hashtable_set (hashtable, "value", fset_option->value);
     if (fset_option->value && (fset_option->type == FSET_OPTION_TYPE_STRING))
     {
-        length = 1 + strlen (fset_option->value) + 1 + 1;
-        value = malloc (length);
-        if (value)
-        {
-            snprintf (value, length, "\"%s\"", fset_option->value);
-            weechat_hashtable_set (hashtable, "quoted_value", value);
-            free (value);
-        }
-        else
-        {
-            weechat_hashtable_set (hashtable,
-                                   "quoted_value", fset_option->value);
-        }
+        weechat_asprintf (&value, "\"%s\"", fset_option->value);
+        weechat_hashtable_set (hashtable, "quoted_value",
+                               (value) ? value : fset_option->value);
+        free (value);
     }
     else
     {
@@ -333,8 +323,7 @@ fset_option_match_filter (struct t_fset_option *fset_option, const char *filter)
             fset_option_filter_hashtable_extra_vars,
             fset_option_filter_hashtable_options);
         match = (result && (strcmp (result, "1") == 0)) ? 1 : 0;
-        if (result)
-            free (result);
+        free (result);
         return match;
     }
     else if (strncmp (filter, "f:", 2) == 0)
@@ -436,60 +425,39 @@ fset_option_set_values (struct t_fset_option *fset_option,
     const char **ptr_string_values;
     void *ptr_default_value, *ptr_value;
     struct t_config_option *ptr_parent_option;
-    int length, *ptr_type, *ptr_min, *ptr_max;
+    int *ptr_type, *ptr_min, *ptr_max;
     char str_value[64], str_allowed_values[4096];
 
     /* file */
-    if (fset_option->file)
-    {
-        free (fset_option->file);
-        fset_option->file = NULL;
-    }
+    free (fset_option->file);
+    fset_option->file = NULL;
     ptr_config_name = weechat_config_option_get_string (option, "config_name");
     fset_option->file = strdup (ptr_config_name);
 
     /* section */
-    if (fset_option->section)
-    {
-        free (fset_option->section);
-        fset_option->section = NULL;
-    }
+    free (fset_option->section);
+    fset_option->section = NULL;
     ptr_section_name = weechat_config_option_get_string (option, "section_name");
     fset_option->section = strdup (ptr_section_name);
 
     /* option */
-    if (fset_option->option)
-    {
-        free (fset_option->option);
-        fset_option->option = NULL;
-    }
+    free (fset_option->option);
+    fset_option->option = NULL;
     ptr_option_name = weechat_config_option_get_string (option, "name");
     fset_option->option = strdup (ptr_option_name);
 
     /* name */
-    if (fset_option->name)
-    {
-        free (fset_option->name);
-        fset_option->name = NULL;
-    }
-    length = strlen (ptr_config_name) + 1 +
-        strlen (ptr_section_name) + 1 +
-        strlen (ptr_option_name) + 1;
-    fset_option->name = malloc (length);
-    if (fset_option->name)
-    {
-        snprintf (fset_option->name, length, "%s.%s.%s",
-                  ptr_config_name,
-                  ptr_section_name,
-                  ptr_option_name);
-    }
+    free (fset_option->name);
+    fset_option->name = NULL;
+    weechat_asprintf (&fset_option->name,
+                      "%s.%s.%s",
+                      ptr_config_name,
+                      ptr_section_name,
+                      ptr_option_name);
 
     /* parent name */
-    if (fset_option->parent_name)
-    {
-        free (fset_option->parent_name);
-        fset_option->parent_name = NULL;
-    }
+    free (fset_option->parent_name);
+    fset_option->parent_name = NULL;
     ptr_parent_name = weechat_config_option_get_string (option, "parent_name");
     fset_option->parent_name = (ptr_parent_name) ? strdup (ptr_parent_name) : NULL;
 
@@ -498,11 +466,8 @@ fset_option_set_values (struct t_fset_option *fset_option,
     fset_option->type = *ptr_type;
 
     /* default value */
-    if (fset_option->default_value)
-    {
-        free (fset_option->default_value);
-        fset_option->default_value = NULL;
-    }
+    free (fset_option->default_value);
+    fset_option->default_value = NULL;
     ptr_default_value = weechat_config_option_get_pointer (option,
                                                            "default_value");
     fset_option_set_value_string (option,
@@ -512,11 +477,8 @@ fset_option_set_values (struct t_fset_option *fset_option,
                                   &fset_option->default_value);
 
     /* value */
-    if (fset_option->value)
-    {
-        free (fset_option->value);
-        fset_option->value = NULL;
-    }
+    free (fset_option->value);
+    fset_option->value = NULL;
     ptr_value = weechat_config_option_get_pointer (option, "value");
     fset_option_set_value_string (option,
                                   fset_option->type,
@@ -525,11 +487,8 @@ fset_option_set_values (struct t_fset_option *fset_option,
                                   &fset_option->value);
 
     /* parent_value */
-    if (fset_option->parent_value)
-    {
-        free (fset_option->parent_value);
-        fset_option->parent_value = NULL;
-    }
+    free (fset_option->parent_value);
+    fset_option->parent_value = NULL;
     if (ptr_parent_name)
     {
         ptr_parent_option = weechat_config_get (ptr_parent_name);
@@ -546,40 +505,28 @@ fset_option_set_values (struct t_fset_option *fset_option,
     }
 
     /* min value */
-    if (fset_option->min)
-    {
-        free (fset_option->min);
-        fset_option->min = NULL;
-    }
+    free (fset_option->min);
+    fset_option->min = NULL;
     ptr_min = weechat_config_option_get_pointer (option, "min");
     snprintf (str_value, sizeof (str_value), "%d", *ptr_min);
     fset_option->min = strdup (str_value);
 
     /* max value */
-    if (fset_option->max)
-    {
-        free (fset_option->max);
-        fset_option->max = NULL;
-    }
+    free (fset_option->max);
+    fset_option->max = NULL;
     ptr_max = weechat_config_option_get_pointer (option, "max");
     snprintf (str_value, sizeof (str_value), "%d", *ptr_max);
     fset_option->max = strdup (str_value);
 
     /* description */
-    if (fset_option->description)
-    {
-        free (fset_option->description);
-        fset_option->description = NULL;
-    }
+    free (fset_option->description);
+    fset_option->description = NULL;
     ptr_description = weechat_config_option_get_string (option, "description");
     fset_option->description = strdup ((ptr_description) ? ptr_description : "");
 
     /* string_values */
-    if (fset_option->string_values)
-    {
-        free (fset_option->string_values);
-        fset_option->string_values = NULL;
-    }
+    free (fset_option->string_values);
+    fset_option->string_values = NULL;
     ptr_string_values = weechat_config_option_get_pointer (option, "string_values");
     if (ptr_string_values)
     {
@@ -592,11 +539,8 @@ fset_option_set_values (struct t_fset_option *fset_option,
     }
 
     /* allowed_values */
-    if (fset_option->allowed_values)
-    {
-        free (fset_option->allowed_values);
-        fset_option->allowed_values = NULL;
-    }
+    free (fset_option->allowed_values);
+    fset_option->allowed_values = NULL;
     str_allowed_values[0] = '\0';
     switch (fset_option->type)
     {
@@ -799,7 +743,7 @@ fset_option_init_max_length (struct t_fset_option_max_length *max_length)
  */
 
 void
-fset_option_set_max_length_fields_all ()
+fset_option_set_max_length_fields_all (void)
 {
     int i, num_options;
     struct t_fset_option *ptr_fset_option;
@@ -945,32 +889,19 @@ fset_option_free (struct t_fset_option *fset_option)
     if (!fset_option)
         return;
 
-    if (fset_option->file)
-        free (fset_option->file);
-    if (fset_option->section)
-        free (fset_option->section);
-    if (fset_option->option)
-        free (fset_option->option);
-    if (fset_option->name)
-        free (fset_option->name);
-    if (fset_option->parent_name)
-        free (fset_option->parent_name);
-    if (fset_option->default_value)
-        free (fset_option->default_value);
-    if (fset_option->value)
-        free (fset_option->value);
-    if (fset_option->parent_value)
-        free (fset_option->parent_value);
-    if (fset_option->min)
-        free (fset_option->min);
-    if (fset_option->max)
-        free (fset_option->max);
-    if (fset_option->description)
-        free (fset_option->description);
-    if (fset_option->string_values)
-        free (fset_option->string_values);
-    if (fset_option->allowed_values)
-        free (fset_option->allowed_values);
+    free (fset_option->file);
+    free (fset_option->section);
+    free (fset_option->option);
+    free (fset_option->name);
+    free (fset_option->parent_name);
+    free (fset_option->default_value);
+    free (fset_option->value);
+    free (fset_option->parent_value);
+    free (fset_option->min);
+    free (fset_option->max);
+    free (fset_option->description);
+    free (fset_option->string_values);
+    free (fset_option->allowed_values);
 
     free (fset_option);
 }
@@ -998,7 +929,7 @@ fset_option_free_cb (void *data, struct t_arraylist *arraylist, void *pointer)
  */
 
 struct t_arraylist *
-fset_option_get_arraylist_options ()
+fset_option_get_arraylist_options (void)
 {
     return weechat_arraylist_new (100, 1, 0,
                                   &fset_option_compare_options_cb, NULL,
@@ -1010,7 +941,7 @@ fset_option_get_arraylist_options ()
  */
 
 struct t_fset_option_max_length *
-fset_option_get_max_length ()
+fset_option_get_max_length (void)
 {
     struct t_fset_option_max_length *max_length;
 
@@ -1026,7 +957,7 @@ fset_option_get_max_length ()
  */
 
 void
-fset_option_get_options ()
+fset_option_get_options (void)
 {
     struct t_fset_option *new_fset_option, *ptr_fset_option;
     struct t_config_file *ptr_config;
@@ -1126,8 +1057,7 @@ fset_option_get_options ()
 void
 fset_option_set_filter (const char *filter)
 {
-    if (fset_option_filter)
-        free (fset_option_filter);
+    free (fset_option_filter);
     fset_option_filter = (filter && (strcmp (filter, "*") != 0)) ?
         strdup (filter) : NULL;
 }
@@ -1238,7 +1168,7 @@ fset_option_set (struct t_fset_option *fset_option,
                  struct t_gui_buffer *buffer,
                  int set_mode)
 {
-    int use_mute, add_quotes, length_input, input_pos;
+    int use_mute, add_quotes, input_pos;
     char *ptr_value, *str_input, str_pos[32];
     char empty_value[1] = { '\0' };
 
@@ -1253,20 +1183,19 @@ fset_option_set (struct t_fset_option *fset_option,
     else
         ptr_value = (fset_option->value) ? fset_option->value : empty_value;
 
-    length_input = 64 + strlen (fset_option->name) + strlen (ptr_value) + 1;
-    str_input = malloc (length_input);
-    if (!str_input)
-        return;
-
     use_mute = weechat_config_boolean (fset_config_look_use_mute);
     add_quotes = (fset_option->type == FSET_OPTION_TYPE_STRING) ? 1 : 0;
-    snprintf (str_input, length_input,
-              "%s/set %s %s%s%s",
-              (use_mute) ? "/mute " : "",
-              fset_option->name,
-              (add_quotes) ? "\"" : "",
-              ptr_value,
-              (add_quotes) ? "\"" : "");
+    if (weechat_asprintf (
+            &str_input,
+            "%s/set %s %s%s%s",
+            (use_mute) ? "/mute " : "",
+            fset_option->name,
+            (add_quotes) ? "\"" : "",
+            ptr_value,
+            (add_quotes) ? "\"" : "") < 0)
+    {
+        return;
+    }
     weechat_buffer_set (buffer, "input", str_input);
     input_pos = ((use_mute) ? 6 : 0) +  /* "/mute " */
         5 +  /* "/set " */
@@ -1349,7 +1278,7 @@ fset_option_mark_options_matching_filter (const char *filter, int mark)
  */
 
 void
-fset_option_unmark_all ()
+fset_option_unmark_all (void)
 {
     int num_options, marked, set_title, i;
     struct t_fset_option *ptr_fset_option;
@@ -1392,16 +1321,23 @@ int
 fset_option_export (const char *filename, int with_help)
 {
     int num_options, i;
-    char *line;
+    char *filename2, *line;
     FILE *file;
     struct t_fset_option *ptr_fset_option;
     struct t_hashtable *hashtable_pointers, *hashtable_extra_vars;
 
-    file = fopen (filename, "w");
-    if (!file)
+    filename2 = weechat_string_expand_home (filename);
+    if (!filename2)
         return 0;
 
-    chmod (filename, 0600);
+    file = fopen (filename2, "w");
+    if (!file)
+    {
+        free (filename2);
+        return 0;
+    }
+
+    fchmod (fileno (file), 0600);
 
     hashtable_pointers = weechat_hashtable_new (
         8,
@@ -1435,8 +1371,7 @@ fset_option_export (const char *filename, int with_help)
                     NULL);
                 if (line && line[0])
                     fprintf (file, "%s\n", line);
-                if (line)
-                    free (line);
+                free (line);
             }
             line = weechat_string_eval_expression (
                 (ptr_fset_option->value) ?
@@ -1447,21 +1382,83 @@ fset_option_export (const char *filename, int with_help)
                 NULL);
             if (line && line[0])
                 fprintf (file, "%s\n", line);
-            if (line)
-                free (line);
+            free (line);
         }
     }
 
     fclose (file);
 
-    if (hashtable_pointers)
-        weechat_hashtable_free (hashtable_pointers);
-    if (hashtable_extra_vars)
-        weechat_hashtable_free (hashtable_extra_vars);
+    weechat_hashtable_free (hashtable_pointers);
+    weechat_hashtable_free (hashtable_extra_vars);
+    free (filename2);
 
     return 1;
 }
 
+/*
+ * Imports options from a file: all lines starting with "/" are executed.
+ *
+ * Returns:
+ *     -2: not enough memory
+ *     -1: file not found
+ *   >= 0: number of commands executed in file
+ */
+
+int
+fset_option_import (const char *filename)
+{
+    char *filename2, line[4096], *ptr_line;
+    FILE *file;
+    int length, count;
+
+    count = 0;
+
+    filename2 = weechat_string_expand_home (filename);
+    if (!filename2)
+        return -2;
+
+    file = fopen (filename2, "r");
+    if (!file)
+    {
+        free (filename2);
+        return -1;
+    }
+
+    while (!feof (file))
+    {
+        ptr_line = fgets (line, sizeof (line) - 1, file);
+        if (!ptr_line)
+            continue;
+        /* ignore comments */
+        if (ptr_line[0] == '#')
+            continue;
+        /* execute command (if it's a valid command) */
+        if (!weechat_string_input_for_buffer (ptr_line))
+        {
+            /* remove trailing '\r' and '\n' */
+            length = strlen (line) - 1;
+            while ((length >= 0)
+                   && ((line[length] == '\n')
+                       || (line[length] == '\r')))
+            {
+                line[length] = '\0';
+                length--;
+            }
+            if (ptr_line[0])
+            {
+                weechat_command (NULL, ptr_line);
+                count++;
+            }
+        }
+    }
+
+    fclose (file);
+
+    free (filename2);
+
+    return count;
+}
+
 /*
  * Refreshes the fset buffer after the change of an option.
  */
@@ -1556,8 +1553,7 @@ fset_option_config_changed (const char *option_name)
         fset_buffer_refresh (0);
     }
 
-    if (old_name_selected)
-        free (old_name_selected);
+    free (old_name_selected);
 }
 
 /*
@@ -1647,8 +1643,7 @@ fset_option_config_cb (const void *pointer,
         free (info);
         return WEECHAT_RC_OK;
     }
-    if (info)
-        free (info);
+    free (info);
 
     /*
      * we limit the number of options to display with the timer; for example
@@ -1777,7 +1772,7 @@ fset_option_add_to_infolist (struct t_infolist *infolist,
  */
 
 void
-fset_option_print_log ()
+fset_option_print_log (void)
 {
     struct t_fset_option *ptr_fset_option;
     int num_options, i;
@@ -1789,25 +1784,25 @@ fset_option_print_log ()
         if (!ptr_fset_option)
             continue;
         weechat_log_printf ("");
-        weechat_log_printf ("[fset option (addr:0x%lx)]", ptr_fset_option);
-        weechat_log_printf ("  index . . . . . . . . : %d",    ptr_fset_option->index);
-        weechat_log_printf ("  file. . . . . . . . . : '%s'",  ptr_fset_option->file);
-        weechat_log_printf ("  section . . . . . . . : '%s'",  ptr_fset_option->section);
-        weechat_log_printf ("  option. . . . . . . . : '%s'",  ptr_fset_option->option);
-        weechat_log_printf ("  name. . . . . . . . . : '%s'",  ptr_fset_option->name);
-        weechat_log_printf ("  parent_name . . . . . : '%s'",  ptr_fset_option->parent_name);
+        weechat_log_printf ("[fset option (addr:%p)]", ptr_fset_option);
+        weechat_log_printf ("  index . . . . . . . . : %d", ptr_fset_option->index);
+        weechat_log_printf ("  file. . . . . . . . . : '%s'", ptr_fset_option->file);
+        weechat_log_printf ("  section . . . . . . . : '%s'", ptr_fset_option->section);
+        weechat_log_printf ("  option. . . . . . . . : '%s'", ptr_fset_option->option);
+        weechat_log_printf ("  name. . . . . . . . . : '%s'", ptr_fset_option->name);
+        weechat_log_printf ("  parent_name . . . . . : '%s'", ptr_fset_option->parent_name);
         weechat_log_printf ("  type. . . . . . . . . : %d ('%s')",
                             ptr_fset_option->type,
                             fset_option_type_string[ptr_fset_option->type]);
-        weechat_log_printf ("  default_value . . . . : '%s'",  ptr_fset_option->default_value);
-        weechat_log_printf ("  value . . . . . . . . : '%s'",  ptr_fset_option->value);
-        weechat_log_printf ("  parent_value. . . . . : '%s'",  ptr_fset_option->parent_value);
-        weechat_log_printf ("  min . . . . . . . . . : '%s'",  ptr_fset_option->min);
-        weechat_log_printf ("  max . . . . . . . . . : '%s'",  ptr_fset_option->max);
-        weechat_log_printf ("  description . . . . . : '%s'",  ptr_fset_option->description);
-        weechat_log_printf ("  string_values . . . . : '%s'",  ptr_fset_option->string_values);
-        weechat_log_printf ("  allowed_values. . . . : '%s'",  ptr_fset_option->allowed_values);
-        weechat_log_printf ("  marked. . . . . . . . : %d",    ptr_fset_option->marked);
+        weechat_log_printf ("  default_value . . . . : '%s'", ptr_fset_option->default_value);
+        weechat_log_printf ("  value . . . . . . . . : '%s'", ptr_fset_option->value);
+        weechat_log_printf ("  parent_value. . . . . : '%s'", ptr_fset_option->parent_value);
+        weechat_log_printf ("  min . . . . . . . . . : '%s'", ptr_fset_option->min);
+        weechat_log_printf ("  max . . . . . . . . . : '%s'", ptr_fset_option->max);
+        weechat_log_printf ("  description . . . . . : '%s'", ptr_fset_option->description);
+        weechat_log_printf ("  string_values . . . . : '%s'", ptr_fset_option->string_values);
+        weechat_log_printf ("  allowed_values. . . . : '%s'", ptr_fset_option->allowed_values);
+        weechat_log_printf ("  marked. . . . . . . . : %d", ptr_fset_option->marked);
     }
 }
 
@@ -1820,7 +1815,7 @@ fset_option_print_log ()
  */
 
 int
-fset_option_init ()
+fset_option_init (void)
 {
     fset_options = fset_option_get_arraylist_options ();
     if (!fset_options)
@@ -1896,7 +1891,7 @@ fset_option_init ()
  */
 
 void
-fset_option_end ()
+fset_option_end (void)
 {
     if (fset_options)
     {
@@ -1904,16 +1899,10 @@ fset_option_end ()
         fset_options = NULL;
     }
     fset_option_count_marked = 0;
-    if (fset_option_max_length)
-    {
-        free (fset_option_max_length);
-        fset_option_max_length = NULL;
-    }
-    if (fset_option_filter)
-    {
-        free (fset_option_filter);
-        fset_option_filter = NULL;
-    }
+    free (fset_option_max_length);
+    fset_option_max_length = NULL;
+    free (fset_option_filter);
+    fset_option_filter = NULL;
     if (fset_option_filter_hashtable_pointers)
     {
         weechat_hashtable_free (fset_option_filter_hashtable_pointers);
@@ -1934,4 +1923,9 @@ fset_option_end ()
         weechat_hashtable_free (fset_option_timer_options_changed);
         fset_option_timer_options_changed = NULL;
     }
+    if (fset_option_timer_hook)
+    {
+        weechat_unhook (fset_option_timer_hook);
+        fset_option_timer_hook = NULL;
+    }
 }
