@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -33,6 +33,6 @@ extern struct t_hdata *fset_hdata_config_section;
 extern struct t_hdata *fset_hdata_config_option;
 extern struct t_hdata *fset_hdata_fset_option;
 
-extern void fset_add_bar ();
+extern void fset_add_bar (void);
 
 #endif /* WEECHAT_PLUGIN_FSET_H */
