@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -52,7 +52,7 @@ extern int irc_buffer_close_cb (const void *pointer, void *data,
 extern int irc_buffer_nickcmp_cb (const void *pointer, void *data,
                                   struct t_gui_buffer *buffer,
                                   const char *nick1, const char *nick2);
-extern struct t_gui_buffer *irc_buffer_search_server_lowest_number ();
+extern struct t_gui_buffer *irc_buffer_search_server_lowest_number (void);
 extern struct t_gui_buffer *irc_buffer_search_private_lowest_number (struct t_irc_server *server);
 extern void irc_buffer_move_near_server (struct t_irc_server *server,
                                          int list_buffer, int channel_type,
