@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -59,12 +59,12 @@ extern int irc_ignore_check (struct t_irc_server *server,
                              const char *channel, const char *nick,
                              const char *host);
 extern void irc_ignore_free (struct t_irc_ignore *ignore);
-extern void irc_ignore_free_all ();
+extern void irc_ignore_free_all (void);
 extern struct t_hdata *irc_ignore_hdata_ignore_cb (const void *pointer,
                                                    void *data,
                                                    const char *hdata_name);
 extern int irc_ignore_add_to_infolist (struct t_infolist *infolist,
                                        struct t_irc_ignore *ignore);
-extern void irc_ignore_print_log ();
+extern void irc_ignore_print_log (void);
 
 #endif /* WEECHAT_PLUGIN_IRC_IGNORE_H */
