@@ -1,7 +1,7 @@
 /*
  * irc-info.c - info, infolist and hdata hooks for IRC plugin
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -53,13 +53,7 @@ irc_info_create_string_with_pointer (char **string, void *pointer)
         *string = NULL;
     }
     if (pointer)
-    {
-        *string = malloc (64);
-        if (*string)
-        {
-            snprintf (*string, 64, "0x%lx", (unsigned long)pointer);
-        }
-    }
+        weechat_asprintf (string, "0x%lx", (unsigned long)pointer);
 }
 
 /*
@@ -1341,7 +1335,7 @@ irc_info_infolist_irc_color_weechat_cb (const void *pointer, void *data,
  */
 
 void
-irc_info_init ()
+irc_info_init (void)
 {
     /* info hooks */
     weechat_hook_info (
