@@ -1,7 +1,7 @@
 /*
  * irc-list.c - functions for IRC list buffer
  *
- * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -1167,7 +1167,7 @@ irc_list_reset (struct t_irc_server *server)
  */
 
 struct t_irc_list *
-irc_list_alloc ()
+irc_list_alloc (void)
 {
     struct t_irc_list *list;
 
@@ -1348,7 +1348,7 @@ irc_list_mouse_hsignal_cb (const void *pointer, void *data, const char *signal,
  */
 
 void
-irc_list_init ()
+irc_list_init (void)
 {
     struct t_hashtable *keys;
 
@@ -1409,7 +1409,7 @@ irc_list_init ()
  */
 
 void
-irc_list_end ()
+irc_list_end (void)
 {
     if (irc_list_filter_hashtable_pointers)
     {
