@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -59,8 +59,8 @@ extern int irc_nick_has_prefix_mode (struct t_irc_server *server,
                                      char prefix_mode);
 extern const char *irc_nick_get_prefix_color_name (struct t_irc_server *server,
                                                    char prefix);
-extern void irc_nick_nicklist_set_prefix_color_all ();
-extern void irc_nick_nicklist_set_color_all ();
+extern void irc_nick_nicklist_set_prefix_color_all (void);
+extern void irc_nick_nicklist_set_color_all (void);
 extern struct t_irc_nick *irc_nick_new_in_channel (struct t_irc_server *server,
                                                    struct t_irc_channel *channel,
                                                    const char *nickname,
