@@ -1,7 +1,7 @@
 /*
  * logger-info.c - info and infolist hooks for logger plugin
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -143,7 +143,7 @@ logger_info_infolist_logger_buffer_cb (const void *pointer, void *data,
  */
 
 void
-logger_info_init ()
+logger_info_init (void)
 {
     /* info hooks */
     weechat_hook_info (
