@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -36,12 +36,13 @@ extern struct t_hook *logger_hook_print;
 
 extern int logger_check_conditions (struct t_gui_buffer *buffer,
                                     const char *conditions);
-extern int logger_create_directory ();
+extern int logger_create_directory (void);
 extern char *logger_build_option_name (struct t_gui_buffer *buffer);
 extern int logger_get_level_for_buffer (struct t_gui_buffer *buffer);
 extern char *logger_get_filename (struct t_gui_buffer *buffer);
 extern int logger_print_cb (const void *pointer, void *data,
-                            struct t_gui_buffer *buffer, time_t date,
+                            struct t_gui_buffer *buffer,
+                            time_t date, int date_usec,
                             int tags_count, const char **tags,
                             int displayed, int highlight,
                             const char *prefix, const char *message);
