@@ -2,7 +2,7 @@
  * weechat-php.c - PHP plugin for WeeChat
  *
  * Copyright (C) 2006-2017 Adam Saponara <as@php.net>
- * Copyright (C) 2017-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2017-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -277,6 +277,7 @@ const zend_function_entry weechat_functions[] = {
     PHP_FE(weechat_completion_new, arginfo_weechat_completion_new)
     PHP_FE(weechat_completion_search, arginfo_weechat_completion_search)
     PHP_FE(weechat_completion_get_string, arginfo_weechat_completion_get_string)
+    PHP_FE(weechat_completion_set, arginfo_weechat_completion_set)
     PHP_FE(weechat_completion_list_add, arginfo_weechat_completion_list_add)
     PHP_FE(weechat_completion_free, arginfo_weechat_completion_free)
     PHP_FE(weechat_info_get, arginfo_weechat_info_get)
@@ -797,7 +798,7 @@ weechat_php_unload_name (const char *name)
  */
 
 void
-weechat_php_unload_all ()
+weechat_php_unload_all (void)
 {
     while (php_scripts)
     {
