@@ -1,7 +1,7 @@
 /*
  * plugin-api-info.c - extra info functions for plugin API
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -2125,7 +2125,7 @@ plugin_api_infolist_window_cb (const void *pointer, void *data,
  */
 
 void
-plugin_api_info_init ()
+plugin_api_info_init (void)
 {
     /* WeeChat core info hooks */
     hook_info (NULL, "version",
