@@ -1,7 +1,7 @@
 /*
  * plugin-api.c - extra functions for plugin API
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -693,7 +693,7 @@ plugin_api_infolist_free (struct t_infolist *infolist)
  */
 
 void
-plugin_api_init ()
+plugin_api_init (void)
 {
     /* WeeChat core modifiers */
     hook_modifier (NULL, "color_decode",
