@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -92,6 +92,6 @@ extern time_t plugin_api_infolist_time (struct t_infolist *infolist,
                                         const char *var);
 extern void plugin_api_infolist_free (struct t_infolist *infolist);
 
-extern void plugin_api_init ();
+extern void plugin_api_init (void);
 
 #endif /* WEECHAT_PLUGIN_PLUGIN_API_H */
