@@ -1,7 +1,7 @@
 /*
  * relay-api-msg.c - build JSON messages for "api" protocol
  *
- * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -248,7 +248,7 @@ relay_api_msg_send_error_json (struct t_relay_client *client,
 {
     cJSON *json;
     int num_bytes;
-    char *error_msg, *str_json;
+    char *str_json;
 
     if (!client || !message || !format)
         return -1;
@@ -259,43 +259,37 @@ relay_api_msg_send_error_json (struct t_relay_client *client,
 
     num_bytes = -1;
 
+    json = cJSON_CreateObject ();
+    if (!json)
+        return -1;
+
+    cJSON_AddItemToObject (json, "error", cJSON_CreateString (vbuffer));
+
     if (client->websocket == RELAY_CLIENT_WEBSOCKET_READY)
     {
         /*
          * with established websocket, we return JSON string instead of
          * an HTTP response
          */
-        json = cJSON_CreateObject ();
-        if (json)
-        {
-            cJSON_AddItemToObject (json, "error", cJSON_CreateString (vbuffer));
-            num_bytes = relay_api_msg_send_json_internal (
-                client,
-                return_code,
-                message,
-                NULL,  /* event_name */
-                -1,    /* event_buffer_id */
-                headers,
-                NULL,  /* body_type */
-                json);
-            cJSON_Delete (json);
-        }
+        num_bytes = relay_api_msg_send_json_internal (
+            client,
+            return_code,
+            message,
+            NULL,  /* event_name */
+            -1,    /* event_buffer_id */
+            headers,
+            NULL,  /* body_type */
+            json);
     }
     else
     {
-        error_msg = weechat_string_replace (vbuffer, "\"", "\\\"");
-        if (error_msg)
-        {
-            if (weechat_asprintf (&str_json, "{\"error\": \"%s\"}", error_msg) >= 0)
-            {
-                num_bytes = relay_http_send_json (client, return_code, message,
-                                                  headers, str_json);
-                free (str_json);
-            }
-            free (error_msg);
-        }
+        str_json = cJSON_PrintUnformatted (json);
+        num_bytes = relay_http_send_json (client, return_code, message,
+                                          headers, str_json);
+        free (str_json);
     }
 
+    cJSON_Delete (json);
     free (vbuffer);
     return num_bytes;
 }
@@ -721,6 +715,72 @@ relay_api_msg_nick_group_to_json (struct t_gui_nick_group *nick_group,
     return json;
 }
 
+/*
+ * Creates a JSON object with a completion entry.
+ */
+
+cJSON *
+relay_api_msg_completion_to_json (struct t_gui_completion *completion)
+{
+    struct t_hdata *hdata;
+    struct t_gui_completion *pointer;
+    struct t_gui_completion_word *word;
+    const char *ptr_string;
+    struct t_arraylist *ptr_list;
+    cJSON *json, *json_array;
+    int context, i, size;
+
+    hdata = relay_hdata_completion;
+    pointer = completion;
+
+    json = cJSON_CreateObject ();
+    if (!json)
+        return NULL;
+
+    if (!completion)
+        return json;
+
+    ptr_list = weechat_hdata_pointer (relay_hdata_completion, completion, "list");
+    if (!ptr_list)
+        return json;
+
+    /* context */
+    context = weechat_hdata_integer (relay_hdata_completion, completion, "context");
+    switch (context)
+    {
+        case 0:
+            MSG_ADD_STR_PTR("context", "null");
+            break;
+        case 1:
+            MSG_ADD_STR_PTR("context", "command");
+            break;
+        case 2:
+            MSG_ADD_STR_PTR("context", "command_arg");
+            break;
+        default:
+            MSG_ADD_STR_PTR("context", "auto");
+            break;
+    }
+
+    MSG_ADD_HDATA_STR("base_word", "base_word");
+    MSG_ADD_HDATA_VAR(Number, "position_replace", integer, "position_replace");
+    MSG_ADD_HDATA_VAR(Bool, "add_space", integer, "add_space");
+
+    json_array = cJSON_CreateArray ();
+    size = weechat_arraylist_size (ptr_list);
+    for (i = 0; i < size; i++)
+    {
+        word = (struct t_gui_completion_word *)weechat_arraylist_get (ptr_list, i);
+        cJSON_AddItemToArray (
+            json_array,
+            cJSON_CreateString (
+                weechat_hdata_string (relay_hdata_completion_word, word, "word")));
+    }
+    cJSON_AddItemToObject (json, "list", json_array);
+
+    return json;
+}
+
 /*
  * Creates a JSON object with a hotlist entry.
  */
