@@ -1,7 +1,7 @@
 /*
  * relay-api-protocol.c - API protocol for relay to client
  *
- * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -713,6 +713,7 @@ RELAY_API_PROTOCOL_CALLBACK(input)
     if (!json_body)
         return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
 
+    /* get buffer either by id or by name */
     ptr_buffer = NULL;
     json_buffer_id = cJSON_GetObjectItem (json_body, "buffer_id");
     if (json_buffer_id)
@@ -726,7 +727,7 @@ RELAY_API_PROTOCOL_CALLBACK(input)
             {
                 relay_api_msg_send_error_json (
                     client,
-                    RELAY_HTTP_404_NOT_FOUND, NULL,
+                    RELAY_HTTP_400_BAD_REQUEST, NULL,
                     "Buffer \"%lld\" not found",
                     (long long)cJSON_GetNumberValue (json_buffer_id));
                 cJSON_Delete (json_body);
@@ -747,7 +748,7 @@ RELAY_API_PROTOCOL_CALLBACK(input)
                 {
                     relay_api_msg_send_error_json (
                         client,
-                        RELAY_HTTP_404_NOT_FOUND, NULL,
+                        RELAY_HTTP_400_BAD_REQUEST, NULL,
                         "Buffer \"%s\" not found",
                         ptr_buffer_name);
                     cJSON_Delete (json_body);
@@ -819,6 +820,138 @@ RELAY_API_PROTOCOL_CALLBACK(input)
     return RELAY_API_PROTOCOL_RC_OK;
 }
 
+/*
+ * Callback for resource "completion".
+ *
+ * Routes:
+ *   POST /api/completion
+ */
+
+RELAY_API_PROTOCOL_CALLBACK(completion)
+{
+    cJSON *json_response, *json_body;
+    cJSON *json_buffer_id, *json_buffer_name;
+    cJSON *json_command, *json_position;
+    const char *ptr_buffer_name, *ptr_command;
+    int position;
+    char str_id[64];
+    struct t_gui_completion *ptr_completion;
+    struct t_gui_buffer *ptr_buffer;
+
+    json_body = cJSON_Parse (client->http_req->body);
+    if (!json_body)
+        return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
+
+    /* get buffer either by id or by name */
+    ptr_buffer = NULL;
+    json_buffer_id = cJSON_GetObjectItem (json_body, "buffer_id");
+    if (json_buffer_id)
+    {
+        if (cJSON_IsNumber (json_buffer_id))
+        {
+            snprintf (str_id, sizeof(str_id),
+                      "%lld", (long long)cJSON_GetNumberValue (json_buffer_id));
+            ptr_buffer = weechat_buffer_search ("==id", str_id);
+            if (!ptr_buffer)
+            {
+                relay_api_msg_send_error_json (
+                    client,
+                    RELAY_HTTP_400_BAD_REQUEST, NULL,
+                    "Buffer \"%lld\" not found",
+                    (long long)cJSON_GetNumberValue (json_buffer_id));
+                cJSON_Delete (json_body);
+                return RELAY_API_PROTOCOL_RC_OK;
+            }
+        }
+    }
+    else
+    {
+        json_buffer_name = cJSON_GetObjectItem (json_body, "buffer_name");
+        if (json_buffer_name)
+        {
+            if (cJSON_IsString (json_buffer_name))
+            {
+                ptr_buffer_name = cJSON_GetStringValue (json_buffer_name);
+                ptr_buffer = weechat_buffer_search ("==", ptr_buffer_name);
+                if (!ptr_buffer)
+                {
+                    relay_api_msg_send_error_json (
+                        client,
+                        RELAY_HTTP_400_BAD_REQUEST, NULL,
+                        "Buffer \"%s\" not found",
+                        ptr_buffer_name);
+                    cJSON_Delete (json_body);
+                    return RELAY_API_PROTOCOL_RC_OK;
+                }
+            }
+        }
+        else
+        {
+            ptr_buffer = weechat_buffer_search_main ();
+        }
+    }
+    if (!ptr_buffer)
+    {
+        cJSON_Delete (json_body);
+        return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
+    }
+
+    /* get command and position (optional) from input json object */
+    json_command = cJSON_GetObjectItem (json_body, "command");
+    if (json_command && cJSON_IsString (json_command))
+    {
+        ptr_command = cJSON_GetStringValue (json_command);
+    }
+    else
+    {
+        cJSON_Delete (json_body);
+        return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
+    }
+    json_position = cJSON_GetObjectItem (json_body, "position");
+    if (json_position)
+    {
+        if (cJSON_IsNumber (json_position))
+        {
+            position = cJSON_GetNumberValue (json_position);
+        }
+        else
+        {
+            cJSON_Delete (json_body);
+            return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
+        }
+    }
+    else
+    {
+        position = strlen (ptr_command);
+    }
+
+    /* perform completion */
+    ptr_completion = weechat_completion_new (ptr_buffer);
+    if (!ptr_completion)
+    {
+        cJSON_Delete (json_body);
+        return RELAY_API_PROTOCOL_RC_MEMORY;
+    }
+
+    if (!weechat_completion_search (ptr_completion, ptr_command, position, 1))
+    {
+        weechat_completion_free (ptr_completion);
+        cJSON_Delete (json_body);
+        return RELAY_API_PROTOCOL_RC_BAD_REQUEST;
+    }
+
+    /* create response */
+    json_response = relay_api_msg_completion_to_json (ptr_completion);
+    relay_api_msg_send_json (client, RELAY_HTTP_200_OK, NULL, "completion",
+                             json_response);
+
+    cJSON_Delete (json_response);
+    cJSON_Delete (json_body);
+    weechat_completion_free (ptr_completion);
+
+    return RELAY_API_PROTOCOL_RC_OK;
+}
+
 /*
  * Callback for resource "ping".
  *
@@ -979,8 +1112,8 @@ relay_api_protocol_recv_json_request (struct t_relay_client *client,
     return;
 
 error:
-    relay_api_msg_send_json (client, RELAY_HTTP_400_BAD_REQUEST,
-                             NULL, NULL, NULL);
+    relay_api_msg_send_error_json (client, RELAY_HTTP_400_BAD_REQUEST,
+                                   NULL, RELAY_HTTP_ERROR_BAD_REQUEST);
 }
 
 /*
@@ -1032,8 +1165,11 @@ relay_api_protocol_recv_json (struct t_relay_client *client, const char *json)
     json_obj = cJSON_Parse (json);
     if (!json_obj)
     {
-        relay_api_msg_send_json (client, RELAY_HTTP_400_BAD_REQUEST,
-                                 NULL, NULL, NULL);
+        relay_api_msg_send_error_json (
+            client,
+            RELAY_HTTP_400_BAD_REQUEST,
+            NULL,
+            RELAY_HTTP_ERROR_BAD_REQUEST ": invalid JSON");
         return;
     }
 
@@ -1060,18 +1196,21 @@ void
 relay_api_protocol_recv_http (struct t_relay_client *client)
 {
     int i, num_args;
+    char str_error[1024];
     enum t_relay_api_protocol_rc return_code;
     struct t_relay_api_protocol_cb protocol_cb[] = {
-        /* method, resource, auth, min args, max args, callback */
-        { "OPTIONS", "*",         0, 0, -1, &relay_api_protocol_cb_options   },
-        { "POST",    "handshake", 0, 0,  0, &relay_api_protocol_cb_handshake },
-        { "GET",     "version",   1, 0,  0, &relay_api_protocol_cb_version   },
-        { "GET",     "buffers",   1, 0,  3, &relay_api_protocol_cb_buffers   },
-        { "GET",     "hotlist",   1, 0,  3, &relay_api_protocol_cb_hotlist   },
-        { "POST",    "input",     1, 0,  0, &relay_api_protocol_cb_input     },
-        { "POST",    "ping",      1, 0,  0, &relay_api_protocol_cb_ping      },
-        { "POST",    "sync",      1, 0,  0, &relay_api_protocol_cb_sync      },
-        { NULL,      NULL,        0, 0,  0, NULL                             },
+        /* method,   resource,     auth, args,   callback                */
+        /*                               min,max                         */
+        { "OPTIONS", "*",          0,    0, -1,  RELAY_API_CB(options)    },
+        { "POST",    "handshake",  0,    0,  0,  RELAY_API_CB(handshake)  },
+        { "GET",     "version",    1,    0,  0,  RELAY_API_CB(version)    },
+        { "GET",     "buffers",    1,    0,  3,  RELAY_API_CB(buffers)    },
+        { "GET",     "hotlist",    1,    0,  3,  RELAY_API_CB(hotlist)    },
+        { "POST",    "input",      1,    0,  0,  RELAY_API_CB(input)      },
+        { "POST",    "completion", 1,    0,  0,  RELAY_API_CB(completion) },
+        { "POST",    "ping",       1,    0,  0,  RELAY_API_CB(ping)       },
+        { "POST",    "sync",       1,    0,  0,  RELAY_API_CB(sync)       },
+        { NULL,      NULL,         0,    0,  0,  NULL                     },
     };
 
     if (!client->http_req || RELAY_STATUS_HAS_ENDED(client->status))
@@ -1091,15 +1230,15 @@ relay_api_protocol_recv_http (struct t_relay_client *client)
                         client->http_req->body);
     }
 
-    if ((client->http_req->num_path_items < 2) || !client->http_req->path_items
-        || !client->http_req->path_items[0] || !client->http_req->path_items[1])
+    if ((client->http_req->num_path_items < 2)
+        || !client->http_req->path_items
+        || !client->http_req->path_items[0]
+        || !client->http_req->path_items[1]
+        || (strcmp (client->http_req->path_items[0], "api") != 0))
     {
         goto error_not_found;
     }
 
-    if (strcmp (client->http_req->path_items[0], "api") != 0)
-        goto error_not_found;
-
     num_args = client->http_req->num_path_items - 2;
 
     for (i = 0; protocol_cb[i].resource; i++)
@@ -1137,7 +1276,13 @@ relay_api_protocol_recv_http (struct t_relay_client *client)
                     num_args,
                     protocol_cb[i].min_args);
             }
-            goto error_not_found;
+            snprintf (str_error, sizeof (str_error),
+                      "%s: not enough path parameters (min: %d)",
+                      RELAY_HTTP_ERROR_BAD_REQUEST,
+                      protocol_cb[i].min_args);
+            relay_api_msg_send_error_json (client, RELAY_HTTP_400_BAD_REQUEST,
+                                           NULL, str_error);
+            goto error;
         }
 
         if ((protocol_cb[i].max_args >= 0)
@@ -1159,7 +1304,13 @@ relay_api_protocol_recv_http (struct t_relay_client *client)
                     num_args,
                     protocol_cb[i].max_args);
             }
-            goto error_not_found;
+            snprintf (str_error, sizeof (str_error),
+                      "%s: too many path parameters (max: %d)",
+                      RELAY_HTTP_ERROR_BAD_REQUEST,
+                      protocol_cb[i].max_args);
+            relay_api_msg_send_error_json (client, RELAY_HTTP_400_BAD_REQUEST,
+                                           NULL, str_error);
+            goto error;
         }
 
         return_code = (protocol_cb[i].cmd_function) (client);
@@ -1181,11 +1332,13 @@ relay_api_protocol_recv_http (struct t_relay_client *client)
     goto error_not_found;
 
 error_bad_request:
-    relay_api_msg_send_json (client, RELAY_HTTP_400_BAD_REQUEST, NULL, NULL, NULL);
+    relay_api_msg_send_error_json (client, RELAY_HTTP_400_BAD_REQUEST,
+                                   NULL, RELAY_HTTP_ERROR_BAD_REQUEST);
     goto error;
 
 error_not_found:
-    relay_api_msg_send_json (client, RELAY_HTTP_404_NOT_FOUND, NULL, NULL, NULL);
+    relay_api_msg_send_error_json (client, RELAY_HTTP_404_NOT_FOUND,
+                                   NULL, RELAY_HTTP_ERROR_NOT_FOUND);
     goto error;
 
 error_memory:
