@@ -1,7 +1,7 @@
 /*
  * relay-config.c - relay configuration options (file relay.conf)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -105,9 +105,11 @@ struct t_config_option *relay_config_irc_backlog_time_format = NULL;
 
 /* relay config, api section */
 
-struct t_config_option *relay_config_api_remote_get_lines = NULL;
 struct t_config_option *relay_config_api_remote_autoreconnect_delay_growing = NULL;
 struct t_config_option *relay_config_api_remote_autoreconnect_delay_max = NULL;
+struct t_config_option *relay_config_api_remote_get_lines = NULL;
+struct t_config_option *relay_config_api_remote_input_cmd_local = NULL;
+struct t_config_option *relay_config_api_remote_input_cmd_remote = NULL;
 
 /* other */
 
@@ -1043,19 +1045,17 @@ relay_config_create_remote_option (const char *remote_name, int index_option,
                                    const char *value)
 {
     struct t_config_option *ptr_option;
-    int length;
     char *option_name;
 
     ptr_option = NULL;
 
-    length = strlen (remote_name) + 1 +
-        strlen (relay_remote_option_string[index_option]) + 1;
-    option_name = malloc (length);
-    if (!option_name)
+    if (weechat_asprintf (&option_name,
+                          "%s.%s",
+                          remote_name,
+                          relay_remote_option_string[index_option]) < 0)
+    {
         return NULL;
-
-    snprintf (option_name, length, "%s.%s",
-              remote_name, relay_remote_option_string[index_option]);
+    }
 
     switch (index_option)
     {
@@ -1156,7 +1156,7 @@ relay_config_create_option_temp (struct t_relay_remote *temp_remote,
  */
 
 void
-relay_config_use_temp_remotes ()
+relay_config_use_temp_remotes (void)
 {
     struct t_relay_remote *ptr_temp_remote, *next_temp_remote;
     int i, num_options_ok;
@@ -1414,7 +1414,7 @@ relay_config_update_cb (const void *pointer, void *data,
  */
 
 int
-relay_config_init ()
+relay_config_init (void)
 {
     relay_config_file = weechat_config_new (RELAY_CONFIG_PRIO_NAME,
                                             &relay_config_reload, NULL, NULL);
@@ -1853,13 +1853,6 @@ relay_config_init ()
         NULL, NULL, NULL);
     if (relay_config_section_api)
     {
-        relay_config_api_remote_get_lines = weechat_config_new_option (
-            relay_config_file, relay_config_section_api,
-            "remote_get_lines", "integer",
-            N_("number of lines to retrieve on each buffer when connecting "
-               "to a remote relay"),
-            NULL, 0, INT_MAX, "1000", NULL, 0,
-            NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
         relay_config_api_remote_autoreconnect_delay_growing = weechat_config_new_option (
             relay_config_file, relay_config_section_api,
             "remote_autoreconnect_delay_growing", "integer",
@@ -1874,6 +1867,29 @@ relay_config_init ()
                "maximum)"),
             NULL, 0, 3600 * 24 * 7, "600", NULL, 0,
             NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+        relay_config_api_remote_get_lines = weechat_config_new_option (
+            relay_config_file, relay_config_section_api,
+            "remote_get_lines", "integer",
+            N_("number of lines to retrieve on each buffer when connecting "
+               "to a remote relay"),
+            NULL, 0, INT_MAX, "1000", NULL, 0,
+            NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+        relay_config_api_remote_input_cmd_local = weechat_config_new_option (
+            relay_config_file, relay_config_section_api,
+            "remote_input_cmd_local", "string",
+            N_("text displayed after user input when the command would be "
+               "executed locally (NOT sent to the remote WeeChat) "
+               "(note: content is evaluated, see /help eval)"),
+            NULL, 0, 0, "   ${color:green}<local cmd>", NULL, 0,
+            NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+        relay_config_api_remote_input_cmd_remote = weechat_config_new_option (
+            relay_config_file, relay_config_section_api,
+            "remote_input_cmd_remote", "string",
+            N_("text displayed after user input when the command would be "
+               "executed on the remote WeeChat (NOT executed locally) "
+               "(note: content is evaluated, see /help eval)"),
+            NULL, 0, 0, "   ${color:red}<remote cmd>", NULL, 0,
+            NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     }
 
     /* section port */
@@ -1915,7 +1931,7 @@ relay_config_init ()
  */
 
 int
-relay_config_read ()
+relay_config_read (void)
 {
     int rc;
 
@@ -1937,7 +1953,7 @@ relay_config_read ()
  */
 
 int
-relay_config_write ()
+relay_config_write (void)
 {
     return weechat_config_write (relay_config_file);
 }
@@ -1947,7 +1963,7 @@ relay_config_write ()
  */
 
 void
-relay_config_free ()
+relay_config_free (void)
 {
     weechat_config_free (relay_config_file);
     relay_config_file = NULL;
