@@ -1,7 +1,7 @@
 /*
  * relay-info.c - info and infolist hooks for relay plugin
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -227,7 +227,7 @@ relay_info_infolist_relay_cb (const void *pointer, void *data,
  */
 
 void
-relay_info_init ()
+relay_info_init (void)
 {
     /* info hooks */
     weechat_hook_info (
