@@ -1,7 +1,7 @@
 /*
  * weechat-ruby.c - ruby plugin for WeeChat
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -348,11 +348,10 @@ weechat_ruby_output_flush_ruby (VALUE self)
  */
 
 void
-weechat_ruby_output_flush ()
+weechat_ruby_output_flush (void)
 {
     const char *ptr_command;
     char *temp_buffer, *command;
-    int length;
 
     if (!(*ruby_buffer_output)[0])
         return;
@@ -381,12 +380,10 @@ weechat_ruby_output_flush ()
             }
             else
             {
-                length = 1 + strlen (temp_buffer) + 1;
-                command = malloc (length);
-                if (command)
+                if (weechat_asprintf (&command,
+                                      "%c%s",
+                                      temp_buffer[0], temp_buffer) >= 0)
                 {
-                    snprintf (command, length, "%c%s",
-                              temp_buffer[0], temp_buffer);
                     weechat_command (ruby_eval_buffer,
                                      (command[0]) ? command : " ");
                     free (command);
@@ -850,7 +847,7 @@ weechat_ruby_reload_name (const char *name)
  */
 
 void
-weechat_ruby_unload_all ()
+weechat_ruby_unload_all (void)
 {
     while (ruby_scripts)
     {
