@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -35,7 +35,7 @@ extern void script_buffer_set_current_line (int line);
 extern void script_buffer_show_detail_script (struct t_script_repo *script);
 extern void script_buffer_get_window_info (struct t_gui_window *window,
                                            int *start_line_y, int *chat_height);
-extern void script_buffer_check_line_outside_window ();
+extern void script_buffer_check_line_outside_window (void);
 extern int script_buffer_window_scrolled_cb (const void *pointer, void *data,
                                              const char *signal,
                                              const char *type_data,
@@ -45,9 +45,9 @@ extern int script_buffer_input_cb (const void *pointer, void *data,
                                    const char *input_data);
 extern int script_buffer_close_cb (const void *pointer, void *data,
                                    struct t_gui_buffer *buffer);
-extern void script_buffer_set_callbacks ();
+extern void script_buffer_set_callbacks (void);
 extern void script_buffer_set_keys (struct t_hashtable *hashtable);
-extern void script_buffer_set_localvar_filter ();
-extern void script_buffer_open ();
+extern void script_buffer_set_localvar_filter (void);
+extern void script_buffer_open (void);
 
 #endif /* WEECHAT_PLUGIN_SCRIPT_BUFFER_H */
