@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,7 +20,7 @@
 #ifndef WEECHAT_PLUGIN_SCRIPT_MOUSE_H
 #define WEECHAT_PLUGIN_SCRIPT_MOUSE_H
 
-extern int script_mouse_init ();
-extern void script_mouse_end ();
+extern int script_mouse_init (void);
+extern void script_mouse_end (void);
 
 #endif /* WEECHAT_PLUGIN_SCRIPT_MOUSE_H */
