@@ -1,7 +1,7 @@
 /*
  * spell-info.c - info for spell checker plugin
  *
- * Copyright (C) 2013-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2013-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -80,7 +80,7 @@ spell_info_info_spell_dict_cb (const void *pointer, void *data,
  */
 
 void
-spell_info_init ()
+spell_info_init (void)
 {
     /* info hooks */
     weechat_hook_info (
