@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,10 +26,10 @@ struct t_trigger_context;
 
 extern struct t_gui_buffer *trigger_buffer;
 
-extern void trigger_buffer_set_callbacks ();
+extern void trigger_buffer_set_callbacks (void);
 extern void trigger_buffer_open (const char *filter, int switch_to_buffer);
 extern int trigger_buffer_display_trigger (struct t_trigger *trigger,
                                            struct t_trigger_context *context);
-extern void trigger_buffer_end ();
+extern void trigger_buffer_end (void);
 
 #endif /* WEECHAT_PLUGIN_TRIGGER_BUFFER_H */
