@@ -1,7 +1,7 @@
 /*
  * trigger-command.c - trigger command
  *
- * Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -35,7 +35,7 @@
  */
 
 void
-trigger_command_display_status ()
+trigger_command_display_status (void)
 {
     weechat_printf_date_tags (NULL, 0, "no_trigger",
                               (trigger_enabled) ?
@@ -1252,7 +1252,7 @@ end:
  */
 
 void
-trigger_command_init ()
+trigger_command_init (void)
 {
     weechat_hook_command (
         "trigger",
