@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2021-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -57,6 +57,6 @@ extern struct t_typing_status *typing_status_nick_search (struct t_gui_buffer *b
                                                           const char *nick);
 extern void typing_status_nick_remove (struct t_gui_buffer *buffer,
                                        const char *nick);
-extern void typing_status_end ();
+extern void typing_status_end (void);
 
 #endif /* WEECHAT_PLUGIN_TYPING_STATUS_H */
