@@ -1,7 +1,7 @@
 /*
  * xfer-buffer.c - display xfer list on xfer buffer
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
+#include <limits.h>
 
 #include "../weechat-plugin.h"
 #include "xfer.h"
@@ -217,12 +218,21 @@ xfer_buffer_refresh (const char *hotlist)
                 eta[0] = '\0';
                 if (ptr_xfer->status == XFER_STATUS_ACTIVE)
                 {
-                    snprintf (eta, sizeof (eta),
-                              "%s: %.2llu:%.2llu:%.2llu - ",
-                              _("ETA"),
-                              ptr_xfer->eta / 3600,
-                              (ptr_xfer->eta / 60) % 60,
-                              ptr_xfer->eta % 60);
+                    if (ptr_xfer->eta != ULLONG_MAX)
+                    {
+                        snprintf (eta, sizeof (eta),
+                                  "%s %.2llu:%.2llu:%.2llu - ",
+                                  _("time left:"),
+                                  ptr_xfer->eta / 3600,
+                                  (ptr_xfer->eta / 60) % 60,
+                                  ptr_xfer->eta % 60);
+                    }
+                    else
+                    {
+                        snprintf (eta, sizeof (eta),
+                                  "%s - ",
+                                  _("time left: unknown"));
+                    }
                 }
 
                 /* display second line for file with status, progress bar and estimated time */
@@ -346,7 +356,7 @@ xfer_buffer_close_cb (const void *pointer, void *data,
  */
 
 void
-xfer_buffer_open ()
+xfer_buffer_open (void)
 {
     struct t_hashtable *buffer_props;
 
