@@ -1,7 +1,7 @@
 /*
  * xfer-completion.c - nick completion for xfer chats
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -68,7 +68,7 @@ xfer_completion_nick_cb (const void *pointer, void *data,
  */
 
 void
-xfer_completion_init ()
+xfer_completion_init (void)
 {
     weechat_hook_completion ("nick",
                              N_("nicks of DCC chat"),
