@@ -1,7 +1,7 @@
 /*
  * test-relay-api-protocol.cpp - test relay API protocol (protocol)
  *
- * Copyright (C) 2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2024-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -54,14 +54,15 @@ extern int relay_api_protocol_command_delay;
                   data_sent[0],                                         \
                   strlen ("HTTP/1.1 " #__code " " __message "\r\n"));
 
-#define WEE_CHECK_TEXT(__code, __message, __request, __body)            \
+#define WEE_CHECK_TEXT(__code, __message, __request, __request_body,    \
+                       __body)                                          \
     STRCMP_EQUAL("{\"code\":" #__code ","                               \
                  "\"message\":\"" __message "\","                       \
                  "\"request\":\"" __request "\","                       \
-                 "\"request_body\":" __body ","                         \
+                 "\"request_body\":" __request_body ","                 \
                  "\"request_id\":null,"                                 \
                  "\"body_type\":null,"                                  \
-                 "\"body\":null"                                        \
+                 "\"body\":" __body                                     \
                  "}",                                                   \
                  data_sent[0]);
 
@@ -379,9 +380,9 @@ TEST(RelayApiProtocolWithClient, CbBuffers)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 41\r\n"
+                 "Content-Length: 40\r\n"
                  "\r\n"
-                 "{\"error\": \"Buffer \\\"invalid\\\" not found\"}",
+                 "{\"error\":\"Buffer \\\"invalid\\\" not found\"}",
                  data_sent[0]);
 
     /* error: invalid buffer id */
@@ -389,9 +390,9 @@ TEST(RelayApiProtocolWithClient, CbBuffers)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 37\r\n"
+                 "Content-Length: 36\r\n"
                  "\r\n"
-                 "{\"error\": \"Buffer \\\"123\\\" not found\"}",
+                 "{\"error\":\"Buffer \\\"123\\\" not found\"}",
                  data_sent[0]);
 
     /* error: invalid sub-resource */
@@ -399,19 +400,20 @@ TEST(RelayApiProtocolWithClient, CbBuffers)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 59\r\n"
+                 "Content-Length: 58\r\n"
                  "\r\n"
-                 "{\"error\": \"Sub-resource of buffers not found: \\\"invalid\\\"\"}",
+                 "{\"error\":\"Sub-resource of buffers not found: \\\"invalid\\\"\"}",
                  data_sent[0]);
 
     /* error: too many parameters in path */
     test_client_recv_http ("GET /api/buffers/core.weechat/too/many/parameters",
                            NULL, NULL);
-    STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
+    STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 58\r\n"
+                 "\r\n"
+                 "{\"error\":\"Bad request: too many path parameters (max: 3)\"}",
                  data_sent[0]);
 
     /* get all buffers */
@@ -598,6 +600,87 @@ TEST(RelayApiProtocolWithClient, CbHotlist)
     gui_hotlist_remove_buffer (gui_buffers, 1);
 }
 
+/*
+ * Tests functions:
+ *   relay_api_protocol_cb_completion
+ */
+
+TEST(RelayApiProtocolWithClient, CbCompletion)
+{
+    cJSON *json, *json_obj, *json_array;
+
+    /* error: no body */
+    test_client_recv_http ("POST /api/completion", NULL, NULL);
+    WEE_CHECK_HTTP_CODE(400, "Bad Request");
+    STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
+                 "Access-Control-Allow-Origin: *\r\n"
+                 "Content-Type: application/json; charset=utf-8\r\n"
+                 "Content-Length: 23\r\n"
+                 "\r\n"
+                 "{\"error\":\"Bad request\"}",
+                 data_sent[0]);
+
+    /* error: invalid buffer name */
+    test_client_recv_http ("POST /api/completion",
+                           NULL,
+                           "{\"buffer_name\": \"invalid\", "
+                           "\"command\": \"test\"}");
+    WEE_CHECK_HTTP_CODE(400, "Bad Request");
+    STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
+                 "Access-Control-Allow-Origin: *\r\n"
+                 "Content-Type: application/json; charset=utf-8\r\n"
+                 "Content-Length: 40\r\n"
+                 "\r\n"
+                 "{\"error\":\"Buffer \\\"invalid\\\" not found\"}",
+                 data_sent[0]);
+
+    /* on core buffer, with buffer name. examples from relay protocol examples:
+     * https://weechat.org/files/doc/weechat/stable/weechat_relay_weechat.en.html#command_completion
+     */
+
+    /* completion core.weechat -1 /help fi */
+    test_client_recv_http ("POST /api/completion",
+                           NULL,
+                           "{\"buffer_name\": \"core.weechat\", "
+                           "\"command\": \"/help fi\"}");
+    WEE_CHECK_HTTP_CODE(200, "OK");
+    json = json_body_sent[0];
+    CHECK(json);
+    CHECK(cJSON_IsObject (json));
+    WEE_CHECK_OBJ_STR("command_arg", json, "context");
+    WEE_CHECK_OBJ_STR("fi", json, "base_word");
+    WEE_CHECK_OBJ_NUM(6, json, "position_replace");
+    WEE_CHECK_OBJ_BOOL(0, json, "add_space");
+    json_array = cJSON_GetObjectItem (json, "list");
+    CHECK(json_array);
+    CHECK(cJSON_IsArray (json_array));
+    CHECK(cJSON_GetArraySize (json_array) == 4);
+    STRCMP_EQUAL("fifo", cJSON_GetStringValue (cJSON_GetArrayItem (json_array, 0)));
+    STRCMP_EQUAL("fifo.file.enabled", cJSON_GetStringValue (cJSON_GetArrayItem (json_array, 1)));
+    STRCMP_EQUAL("fifo.file.path", cJSON_GetStringValue (cJSON_GetArrayItem (json_array, 2)));
+    STRCMP_EQUAL("filter", cJSON_GetStringValue (cJSON_GetArrayItem (json_array, 3)));
+
+    /* completion core.weechat 5 /quernick */
+    test_client_recv_http ("POST /api/completion",
+                           NULL,
+                           "{\"buffer_name\": \"core.weechat\", "
+                           "\"command\": \"/quernick\", "
+                           "\"position\": 5}");
+    WEE_CHECK_HTTP_CODE(200, "OK");
+    json = json_body_sent[0];
+    CHECK(json);
+    CHECK(cJSON_IsObject (json));
+    WEE_CHECK_OBJ_STR("command", json, "context");
+    WEE_CHECK_OBJ_STR("quer", json, "base_word");
+    WEE_CHECK_OBJ_NUM(1, json, "position_replace");
+    WEE_CHECK_OBJ_BOOL(1, json, "add_space");
+    json_array = cJSON_GetObjectItem (json, "list");
+    CHECK(json_array);
+    CHECK(cJSON_IsArray (json_array));
+    CHECK(cJSON_GetArraySize (json_array) == 1);
+    STRCMP_EQUAL("query", cJSON_GetStringValue (cJSON_GetArrayItem (json_array, 0)));
+}
+
 /*
  * Tests functions:
  *   relay_api_protocol_cb_input
@@ -613,8 +696,9 @@ TEST(RelayApiProtocolWithClient, CbInput)
     STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 23\r\n"
+                 "\r\n"
+                 "{\"error\":\"Bad request\"}",
                  data_sent[0]);
 
     /* error: invalid buffer name */
@@ -622,12 +706,12 @@ TEST(RelayApiProtocolWithClient, CbInput)
                            NULL,
                            "{\"buffer_name\": \"invalid\", "
                            "\"command\": \"/print test\"}");
-    STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
+    STRCMP_EQUAL("HTTP/1.1 400 Bad Request\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 41\r\n"
+                 "Content-Length: 40\r\n"
                  "\r\n"
-                 "{\"error\": \"Buffer \\\"invalid\\\" not found\"}",
+                 "{\"error\":\"Buffer \\\"invalid\\\" not found\"}",
                  data_sent[0]);
 
     /* on core buffer, without buffer name */
@@ -706,9 +790,9 @@ TEST(RelayApiProtocolWithClient, CbSync)
     STRCMP_EQUAL("HTTP/1.1 403 Forbidden\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 72\r\n"
+                 "Content-Length: 71\r\n"
                  "\r\n"
-                 "{\"error\": \"Sync resource is available only with "
+                 "{\"error\":\"Sync resource is available only with "
                  "a websocket connection\"}",
                  data_sent[0]);
 }
@@ -737,7 +821,7 @@ TEST(RelayApiProtocolWithClient, CbSyncWebsocket)
                  data_sent[0]);
 
     test_client_recv_text ("{\"request\": \"POST /api/sync\"}");
-    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "null");
+    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "null", "null");
 
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_enabled));
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_nicks));
@@ -745,7 +829,7 @@ TEST(RelayApiProtocolWithClient, CbSyncWebsocket)
 
     test_client_recv_text ("{\"request\": \"POST /api/sync\", "
                            "\"body\": {\"sync\": false}}");
-    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":false}");
+    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":false}", "null");
 
     LONGS_EQUAL(0, RELAY_API_DATA(ptr_relay_client, sync_enabled));
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_nicks));
@@ -753,7 +837,7 @@ TEST(RelayApiProtocolWithClient, CbSyncWebsocket)
 
     test_client_recv_text ("{\"request\": \"POST /api/sync\", "
                            "\"body\": {\"sync\": true, \"nicks\": false}}");
-    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":true,\"nicks\":false}");
+    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":true,\"nicks\":false}", "null");
 
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_enabled));
     LONGS_EQUAL(0, RELAY_API_DATA(ptr_relay_client, sync_nicks));
@@ -761,7 +845,7 @@ TEST(RelayApiProtocolWithClient, CbSyncWebsocket)
 
     test_client_recv_text ("{\"request\": \"POST /api/sync\", "
                            "\"body\": {\"sync\": true, \"nicks\": true, \"colors\": \"weechat\"}}");
-    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":true,\"nicks\":true,\"colors\":\"weechat\"}");
+    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":true,\"nicks\":true,\"colors\":\"weechat\"}", "null");
 
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_enabled));
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_nicks));
@@ -769,7 +853,7 @@ TEST(RelayApiProtocolWithClient, CbSyncWebsocket)
 
     test_client_recv_text ("{\"request\": \"POST /api/sync\", "
                            "\"body\": {\"sync\": true, \"nicks\": true, \"colors\": \"strip\"}}");
-    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":true,\"nicks\":true,\"colors\":\"strip\"}");
+    WEE_CHECK_TEXT(204, "No Content", "POST /api/sync", "{\"sync\":true,\"nicks\":true,\"colors\":\"strip\"}", "null");
 
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_enabled));
     LONGS_EQUAL(1, RELAY_API_DATA(ptr_relay_client, sync_nicks));
@@ -802,31 +886,32 @@ TEST(RelayApiProtocolWithClient, RecvJson)
 
     /* error: empty string */
     test_client_recv_text ("");
-    WEE_CHECK_TEXT(400, "Bad Request", "", "null");
+    WEE_CHECK_TEXT(400, "Bad Request", "", "null", "{\"error\":\"Bad request: invalid JSON\"}");
 
     /* error: empty body */
     test_client_recv_text ("{}");
-    WEE_CHECK_TEXT(400, "Bad Request", "", "null");
+    WEE_CHECK_TEXT(400, "Bad Request", "", "null", "{\"error\":\"Bad request\"}");
 
     /* error: empty request */
     test_client_recv_text ("{\"request\": \"\"}");
-    WEE_CHECK_TEXT(400, "Bad Request", "", "null");
+    WEE_CHECK_TEXT(400, "Bad Request", "", "null", "{\"error\":\"Bad request\"}");
 
     /* error: invalid request (number) */
     test_client_recv_text ("{\"request\": 123}");
-    WEE_CHECK_TEXT(400, "Bad Request", "", "null");
+    WEE_CHECK_TEXT(400, "Bad Request", "", "null", "{\"error\":\"Bad request\"}");
 
     /* error: invalid request (string, not a valid request) */
     test_client_recv_text ("{\"request\": \"abc\"}");
-    WEE_CHECK_TEXT(400, "Bad Request", "", "null");
+    WEE_CHECK_TEXT(400, "Bad Request", "", "null", "{\"error\":\"Bad request\"}");
 
     /* error: invalid request (string, resource not found) */
     test_client_recv_text ("{\"request\": \"GET /api/unknown\"}");
-    WEE_CHECK_TEXT(404, "Not Found", "GET /api/unknown", "null");
+    WEE_CHECK_TEXT(404, "Not Found", "GET /api/unknown", "null", "{\"error\":\"Resource not found\"}");
 
     /* error: invalid request (string, resource not found) */
     test_client_recv_text ("{\"request\": \"GET /api/unknown\", \"body\": {\"test\": 123}}");
-    WEE_CHECK_TEXT(404, "Not Found", "GET /api/unknown", "{\"test\":123}");
+    WEE_CHECK_TEXT(404, "Not Found", "GET /api/unknown", "{\"test\":123}",
+                   "{\"error\":\"Resource not found\"}");
 
     /* ping */
     test_client_recv_text ("{\"request\": \"POST /api/ping\", \"request_id\": \"ping\"}");
@@ -881,8 +966,9 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Resource not found\"}",
                  data_sent[0]);
 
     /* resource not found: error 404 */
@@ -890,8 +976,9 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Resource not found\"}",
                  data_sent[0]);
 
     /* resource not found: error 404 */
@@ -899,8 +986,9 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Resource not found\"}",
                  data_sent[0]);
 
     /* resource not found: error 404 */
@@ -908,8 +996,9 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Resource not found\"}",
                  data_sent[0]);
 
     /* resource not found: error 404 */
@@ -917,8 +1006,9 @@ TEST(RelayApiProtocolWithClient, RecvHttp404)
     STRCMP_EQUAL("HTTP/1.1 404 Not Found\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 0\r\n"
-                 "\r\n",
+                 "Content-Length: 30\r\n"
+                 "\r\n"
+                 "{\"error\":\"Resource not found\"}",
                  data_sent[0]);
 }
 
@@ -935,9 +1025,9 @@ TEST(RelayApiProtocolWithClient, RecvHttpMissingPassword)
     STRCMP_EQUAL("HTTP/1.1 401 Unauthorized\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 29\r\n"
+                 "Content-Length: 28\r\n"
                  "\r\n"
-                 "{\"error\": \"Missing password\"}",
+                 "{\"error\":\"Missing password\"}",
                  data_sent[0]);
 }
 
@@ -955,8 +1045,8 @@ TEST(RelayApiProtocolWithClient, RecvHttpInvalidPassword)
     STRCMP_EQUAL("HTTP/1.1 401 Unauthorized\r\n"
                  "Access-Control-Allow-Origin: *\r\n"
                  "Content-Type: application/json; charset=utf-8\r\n"
-                 "Content-Length: 29\r\n"
+                 "Content-Length: 28\r\n"
                  "\r\n"
-                 "{\"error\": \"Invalid password\"}",
+                 "{\"error\":\"Invalid password\"}",
                  data_sent[0]);
 }
